pub struct AppServerImageProvider { /* private fields */ }Expand description
Provider backed by one initialized app-server connection.
Implementations
Sourceimpl AppServerImageProvider
impl AppServerImageProvider
Sourcepub fn new(
rpc: Arc<AppServerRpc>,
sessions: Arc<dyn SessionBindingStore>,
config: AppServerProviderConfig,
) -> Self
pub fn new( rpc: Arc<AppServerRpc>, sessions: Arc<dyn SessionBindingStore>, config: AppServerProviderConfig, ) -> Self
Creates a provider over an existing initialized connection.
Sourcepub fn new_with_inputs(
rpc: Arc<AppServerRpc>,
sessions: Arc<dyn SessionBindingStore>,
config: AppServerProviderConfig,
reference_inputs: AppServerReferenceInputs,
) -> Self
pub fn new_with_inputs( rpc: Arc<AppServerRpc>, sessions: Arc<dyn SessionBindingStore>, config: AppServerProviderConfig, reference_inputs: AppServerReferenceInputs, ) -> Self
Creates a provider over an existing connection with secure references.
Sourcepub fn with_process(
process: Arc<CodexProcess>,
sessions: Arc<dyn SessionBindingStore>,
config: AppServerProviderConfig,
) -> Self
pub fn with_process( process: Arc<CodexProcess>, sessions: Arc<dyn SessionBindingStore>, config: AppServerProviderConfig, ) -> Self
Creates a provider that owns and shuts down its Codex child process.
Sourcepub fn with_process_and_inputs(
process: Arc<CodexProcess>,
sessions: Arc<dyn SessionBindingStore>,
config: AppServerProviderConfig,
reference_inputs: AppServerReferenceInputs,
) -> Self
pub fn with_process_and_inputs( process: Arc<CodexProcess>, sessions: Arc<dyn SessionBindingStore>, config: AppServerProviderConfig, reference_inputs: AppServerReferenceInputs, ) -> Self
Creates an owned provider with secure bridge-staged reference inputs.