pub struct AppServerRpc { /* private fields */ }Expand description
Initialized app-server connection.
Implementations
Sourceimpl AppServerRpc
impl AppServerRpc
Sourcepub async fn connect<R, W>(
reader: R,
writer: W,
config: RpcConfig,
) -> Result<Arc<Self>, BridgeError>
pub async fn connect<R, W>( reader: R, writer: W, config: RpcConfig, ) -> Result<Arc<Self>, BridgeError>
Connects to app-server and completes initialize/initialized exactly once.
Sourcepub fn subscribe(&self) -> Receiver<RpcNotification>
pub fn subscribe(&self) -> Receiver<RpcNotification>
Subscribes before starting a turn so no notification is missed.
Sourcepub async fn request(
&self,
method: &str,
params: Value,
) -> Result<Value, BridgeError>
pub async fn request( &self, method: &str, params: Value, ) -> Result<Value, BridgeError>
Sends a request using the default timeout.
Sourcepub async fn request_until(
&self,
method: &str,
params: Value,
deadline: Instant,
cancellation: CancellationToken,
) -> Result<Value, BridgeError>
pub async fn request_until( &self, method: &str, params: Value, deadline: Instant, cancellation: CancellationToken, ) -> Result<Value, BridgeError>
Sends a request bounded by an absolute deadline and cancellation token.
Sourcepub async fn request_side_effecting_until(
&self,
method: &str,
params: Value,
deadline: Instant,
cancellation: CancellationToken,
) -> Result<Value, BridgeError>
pub async fn request_side_effecting_until( &self, method: &str, params: Value, deadline: Instant, cancellation: CancellationToken, ) -> Result<Value, BridgeError>
Sends a side-effecting request and marks post-flush ambiguity explicitly.